#!/usr/bin/python

import mechanize
import logging

def get_and_log_in(url, username, password, debug=False):
    """Given a url that requires OpenID to continue, an openid username
    (e-mail in our case) and a password, returns a mechanize browser
    object that can be queried for the response with .response()"""
    browser = mechanize.Browser()
    browser.set_handle_robots(False)

    if debug:
        logging.basicConfig(level=logging.DEBUG)
    browser.set_debug_redirects(debug)
    browser.set_debug_responses(debug)
    #browser.set_debug_http(debug)

    browser.open(url)

    # The browser should now be redirected to a form (full of hidden
    # fields) that needs to be submitted to cross over to the openID
    # server.
    browser.select_form(nr=0)
    if options.formsub:
     	browser.submit(name=options.formsub)
    else:
 	browser.submit()

    # Now we're at the login page, and need to enter our access
    # credentials and submit.
    browser.select_form(name="loginform")
    browser["email"] = username
    browser["password"] = password
    try:
        browser.submit()
    except mechanize._response.httperror_seek_wrapper:
        raise nagios_plugin.CriticalError(
                "%s could not be loaded after SSO login" % url)

    # Now we ought to be redirected back to the url we first requested,
    # and will return the browser in that state.
    return browser

def check_content(credentials, content=None):
    """Given a tuple of (url, username, password), an optional content
    string, and a form submit label for multiple submit buttons, try to
    grab the url using openid with the other credentials. If the content
    parameter is provided, raise a nagios critical error unless it
    exists in the resulting document."""
    url, username, password = credentials
    browser = get_and_log_in(url, username, password)
    if content:
        if content not in browser.response().read():
            raise nagios_plugin.CriticalError(
                    "'''%s''' not found in %s" % (content, url))
        print "[OK] '''%s''' found in %s" % (content, url)
    else:
        print "[OK] %s retrieved successfully" % url

if __name__ == '__main__':
    import nagios_plugin
    from optparse import OptionParser
    usage = "usage: %prog [options] <url> <username> <password>"
    parser = OptionParser(usage=usage)
    parser.add_option("-e", "--expect", dest="expect",
            help="string expected in HTML output", action="store",
            type="string")
    parser.add_option("-s", "--submit", dest="formsub",
            help="form submit button label", action="store",
            type="string")
    (options, args) = parser.parse_args()
    if options.expect:
        nagios_plugin.try_check(check_content, args, options.expect)
    else:
        nagios_plugin.try_check(check_content, args)

