#!/usr/bin/env python
#
# Copyright (C) 2010  James Troup <james.troup@canonical.com>
"""Check Asterik IAX peers."""

import optparse
import nagios_plugin

################################################################################
# Example input file:

# Name/Username    Host                 Mask             Port          Status    
# cashew_weetabis  10.63.108.35    (S)  255.255.255.255  4569 (T)      OK (80 ms)
# mango_weetabisk  10.63.108.34    (S)  255.255.255.255  4569 (T)      OK (253 ms)
# weetabisk_nungu  10.63.108.17    (S)  255.255.255.255  4569 (T)      OK (83 ms)
# weetabisk_wasa   10.63.108.1     (S)  255.255.255.255  4569 (T)      OK (12 ms)
# faxbox           10.45.44.3      (D)  255.255.255.255  4569          OK (2 ms) 
# 5 iax2 peers [5 online, 0 offline, 0 unmonitored]

###########################################################################

def check_asterisk_iax():
    """Check Asterisk IAX peers are online.

Expects the output from:

  asterisk -r -x 'iax2 show peers'

in a file and that file is fresh (staleness is configurable).

Simply checks that status is shown as OK for all peers.
"""

    parser = optparse.OptionParser()
    parser.add_option("-a", "--age", dest="file_age", default=1200)
    parser.add_option("-f", "--filename", dest="filename",
                      default="/var/lib/nagios/cat-iax-peers.txt")
    (opts, _) = parser.parse_args()

    nagios_plugin.check_file_freshness(opts.filename, opts.file_age)
    input_file = open(opts.filename, 'r')

    header_line = input_file.readline().rstrip()
    expected_header = "Name/Username    Host                 Mask             Port          Status"
    if header_line != expected_header:
        raise nagios_plugin.UnknownError("Unrecognised header line in 'iax2 show peers' output")

    # Process the last line separately as it's a summary of the status
    # of all peers
    lines = input_file.readlines()
    status_line = lines[-1].strip()
    lines = lines[:-1]

    for line in lines:
        line = line.rstrip()
        if not line:
            continue
        name = line[:15].strip()
        peer_ip = line[17:32].strip()
        status = line[69:].strip()
        if status.split()[0].strip() != "OK":
            raise nagios_plugin.CriticalError("%s / %s has status: %s" % (name, peer_ip, status))
        
    print "All OK: %s" % (status_line)

################################################################################

def main():
    nagios_plugin.try_check(check_asterisk_iax)

################################################################################

if __name__ == "__main__":
    main()
