#!/usr/bin/env python
#
# Copyright (C) 2010  James Troup <james.troup@canonical.com>
"""Check Asterik PRI spans."""

import optparse
import nagios_plugin

################################################################################
#
# Example input:

# PRI span 1/0: Provisioned, Up, Active

###########################################################################

def check_asterisk_spans():
    """Check Asterisk PRI spans are up and active.

Expects the output from:

  asterisk -r -x 'pri show spans'

in a file and that file is fresh (staleness is configurable).

Simply checks that status is shown as provisioned, up and active for all spans.
"""

    parser = optparse.OptionParser()
    parser.add_option("-a", "--age", dest="file_age", default=1200)
    parser.add_option("-c", "--count", dest="num_pris", default=1)
    parser.add_option("-f", "--filename", dest="filename",
                      default="/var/lib/nagios/cat-pri-spans.txt")
    (opts, _) = parser.parse_args()
    
    nagios_plugin.check_file_freshness(opts.filename, opts.file_age)
    pri_count = 0
    for line in open(opts.filename, 'r').readlines():
        line = line.rstrip()
        if not line:
            continue
        if ':' not in line:
            raise nagios_plugin.UnknownError("malformed line in 'pri show spans' output")
        (span, status) = line.split(":")[:2]
        status = status.strip()
        if status.strip() != "Provisioned, Up, Active":
            raise nagios_plugin.CriticalError("%s is %s" % (span, status))
        pri_count += 1

    if pri_count != int(opts.num_pris):
        raise nagios_plugin.CriticalError("Found %d PRIs rather than expected %s"
                                          % (pri_count, opts.num_pris))
    print "All OK: %s spans are provisioned, up and active" % (pri_count)

################################################################################

def main():
    nagios_plugin.try_check(check_asterisk_spans)

################################################################################

if __name__ == "__main__":
    main()
