#!/bin/bash

. /usr/lib/nagios/plugins/utils.sh

set -e

WARN=2
CRITICAL=3
BACKUP_SCRIPT=/srv/chroots/backup-chroot/root/backup.sh

while [ $# -gt 0 ]
do 
        case "$1" in
                -c|--critical)  CRITICAL=$2; shift; shift;;
                -w|--warn)      WARN=$2; shift; shift;;
                --)     shift; break;;
                -*)     echo "You lost me at '$1'"; exit 1;;
                *)      BACKUP_SCRIPT=$1; shift; break;;
        esac
done

WARN_AGE=$(date -d "$WARN days ago" +%s)
CRIT_AGE=$(date -d "$CRITICAL days ago" +%s)

# So that while loop subshells can access these
export NOTBACKEDUP CRITBACKUP WARNBACKUP

# We read our input with crazy process substitution to avoid wiping out our scope
while read line
do
	backupargs=${line#*backup }
	hostname=${backupargs%% *}
	volumes=${backupargs#* }
	for volume in $volumes
	do
		volspec=$hostname-$volume
		stamp=/srv/chroots/backup-chroot/root/stamps/$volspec
		mtime=$(stat -c %Y $stamp 2>/dev/null ||:) 
		if [ -z "$mtime" ]
		then
		       	NOTBACKEDUP="$NOTBACKEDUP $volspec"
			continue
		elif [ $mtime -lt $CRIT_AGE ]
		then
			CRITBACKUP="$CRITBACKUP $volspec"
		elif [ $mtime -lt $WARN_AGE ]
		then
			WARNBACKUP="$WARNBACKUP $volspec"
		fi
	done
done < <(awk 'BEGIN { print "backup crowberry etc var srv home"}; $1=="###BEGIN",$1=="###END" {if($1 ~ /^[^#]/){print};}' $BACKUP_SCRIPT)
# The above awk uses "FROMPATTERN,TOPATTERN" to only pay attention to the   
# text between the BEGIN and END comments, and then in the block uses an
# if() to only print lines that don't begin with #
# Also I seeded in crowberry which we back up from another script.

for i in /srv/chroots/backup-chroot/root/stamps/*-*
do
	volspec=${i##*/}
	hostname=${volspec%%-*}
	volume=${volspec##*-}
	if [ "$hostname" = "crowberry" ]; then
		continue # crowberry is handled by a separate script
	fi
	# Look for uncommented backup lines
	if ! grep -v '^[[:space:]]*#' $BACKUP_SCRIPT | grep -q "[A-Za-z].*ackup $hostname .*$volume"
	then
		OUTOFDATE="$OUTOFDATE $volspec"
	fi
done

echo "MISSING: $NOTBACKEDUP WAY-OLD: $CRITBACKUP KINDA-OLD: $WARNBACKUP CRUFT: $OUTOFDATE"

if [ ! -z "$NOTBACKEDUP" -o ! -z "$CRITBACKUP" ]
then
	exit $STATE_CRITICAL
elif [ ! -z "$WARNBACKUP" -o ! -z "$OUTOFDATE" ]
then
	exit $STATE_WARNING
else
	exit $STATE_OK
fi

