#!/bin/bash

set -e
set -u

# To deploy this check:
# o Make a data directory somewhere
# o run "bzr init" in that directory
# o Ensure the nagios process can access and read the bzr folders
# o Manually download the web page you want to monitor
# o run "bzr add foo.html && bzr commit foo.html -m 'Initial import'"
# o Set up the configuration below
# o Add this to your nagios checks
# o Add a periodic cronjob to download the file again

# When it detects changes, someone will need to manually bzr commit them - this will allow the nagios check to stay failed until the bogon update has been dealt with

# Configuration start
SRCURL="http://www.cymru.com/Documents/bogon-bn-agg.txt"
DATADIR="/var/lib/nagios3/bogon/"
DATAFILE="bogon-bn-agg.txt"
BZR="/usr/bin/bzr"
# Configuration end

if [ ! -d $DATADIR ]; then
	echo "FAIL: $DATADIR does not exist"
	exit 2
fi

cd $DATADIR

# If the file hasn't been modified for more than 24 hours
#  we have a problem with the updater cronjob
CURRTIME=`date +"%s"`
DATAMTIME=`stat -c "%Z" ${DATADIR}${DATAFILE}`
let "TIMEDIFF = $CURRTIME - $DATAMTIME"

if [ "$TIMEDIFF" -gt "172800" ]; then
  # DATAFILE is > 24 hours old
  echo "FAIL: ${DATADIR}${DATAFILE} too old"
  exit 2
fi

set +e
OUTPUT=`$BZR diff 2>/dev/null`
set -e

if [ -z "$OUTPUT" ]; then
  # No changes, all is well
  echo "OK: No updates"
  exit 0
else
  # Something has changed
  echo "WARNING: Routable internet address blocks are being firewalled"
  exit 1
fi
