#!/bin/sh

set -e
set -u

# Reference for CISCO-CONFIG-MAN-MIB:
# http://tools.cisco.com/Support/SNMP/do/BrowseOID.do?local=en&translate=Translate&objectInput=1.3.6.1.4.1.9.9.43.1.1.1#oidContent
ccmHistoryRunningLastChanged=".1.3.6.1.4.1.9.9.43.1.1.1.0"
ccmHistoryRunningLastSaved=".1.3.6.1.4.1.9.9.43.1.1.2.0"
ccmHistoryStartupLastChanged=".1.3.6.1.4.1.9.9.43.1.1.3.0"

SNMP_ARGS="-Otv -v2c -c"
host=""
community=""

set -- $(/usr/bin/getopt -u -l hostname: -l community: H:C: $*)
while [ $# -gt 0 ]; do
   case "$1" in
      "-H"|"--hostname")
          host=$2
          shift
          shift
      ;;
      "-C"|"--community")
          community=$2
          shift
          shift
      ;;
      *)
          shift
      ;;
   esac
done

if [ "$community" = "" -o "$host" = "" ]; then
   echo "Usage: check_cisco_config.sh -H <ip_address> -C <community>"
   exit 3
fi

if [ -x /usr/bin/snmpget ]; then
   startupChanged=$(/usr/bin/snmpget $SNMP_ARGS $community $host $ccmHistoryStartupLastChanged)
   runningChanged=$(/usr/bin/snmpget $SNMP_ARGS $community $host $ccmHistoryRunningLastChanged)
   runningSaved=$(/usr/bin/snmpget $SNMP_ARGS $community $host $ccmHistoryRunningLastSaved)

    # Different Cisco devices report these three variables differently
    # (see https://pastebin.canonical.com/128116/), so we use either
    # runningSaved or startupChanged as evidence that config has been written.
    # We also use -ge instead of -gt to allow for the case where NX-OS 6.x on
    # on Nexus 3000 series reports 0 for all three variables if config has not
    # changed since startup.

   if [ "$startupChanged" -ge "$runningChanged" -o "$runningSaved" -ge "$runningChanged" ]; then
      echo "Running config has safely been written to flash."
      exit 0
   else
      echo "Running config has not been saved - please write mem or equivalent."
      exit 2
   fi
fi

echo "There is a disturbance in the force."
exit 3
