#!/usr/bin/python
#
# check_esendex.py - checks ESendex for our SMS balance
# partially cribbed from check_isd_forms.py and check_rabbitmq

import sys
import xml.dom.minidom
import urllib2
from optparse import OptionParser

# Nagios exit codes
OK = 0
WARNING = 1
CRITICAL = 2
UNKNOWN = 3

class NagiosOptionParser(OptionParser):
    """An option parser that exits with status 3 instead of default 2"""
    def error(self, msg):
        print msg
        sys.exit(UNKNOWN)

def get_args():
    usage = "Usage: %prog -u USERNAME -p PASSWORD -w WARNLEVEL -c CRITLEVEL"
    parser = NagiosOptionParser(usage=usage)
    parser.add_option("-u", dest="user", help="ESendex Username")
    parser.add_option("-p", dest="passwd", help="ESendex Password")
    parser.add_option("-w", dest="warn", help="Warning threshold for credits")
    parser.add_option("-c", dest="crit", help="Critical threshold for credits")

    (options, args) = parser.parse_args()
    if None in [options.user, options.passwd, options.warn, options.crit]:
        parser.error("ERROR: All arguments must be specified")
    return options

def prepare_url_opener(args):
    password_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
    password_mgr.add_password("EsendexAPI", "https://api.esendex.com",
                              args.user, args.passwd)
    handler = urllib2.HTTPBasicAuthHandler(password_mgr)
    opener = urllib2.build_opener(handler)
    return opener

def main():
    args = get_args()
    opener = prepare_url_opener(args)
    try:
        response = opener.open("https://api.esendex.com/v1.0/accounts")
        data = response.read()
        doc = xml.dom.minidom.parseString(data)
        element = doc.documentElement.getElementsByTagName("messagesremaining")
        remaining = int(element[0].childNodes[0].wholeText)
        if remaining < int(args.crit):
            print("CRITICAL: Only %d SMS credits remaining" % remaining)
            sys.exit(CRITICAL)
        elif remaining < int(args.warn):
            print("WARNING: Only %d SMS credits remaining" % remaining)
            sys.exit(WARNING)
        else:
            print("OK: %d SMS credits remaining" % remaining)
            sys.exit(OK)
    except Exception:
        print "ERROR: Unable to check remaining credits"
        sys.exit(2)

if __name__ == '__main__':
    main()

