#!/usr/bin/env python

# Copyright (C) 2007, 2008 James Troup <james.troup@canonical.com>

import os
import stat

import nagios_plugin

################################################################################

def check_up_to_date():
    filename = "/var/lib/nagios/etc-bzr-status.txt"
    nagios_plugin.check_file_freshness(filename, 21600)
    s = os.stat(filename)
    if  s[stat.ST_SIZE] > 0:
        raise nagios_plugin.WarnError("/etc bzr tree is not up-to-date, please commit any uncommitted changes.")

############################################################

def check_perms_and_ownership():
    for directory in [ "/etc/.bzr", "/etc/backup.bzr" ]:
        if not os.path.exists(directory) and directory == "/etc/backup.bzr":
            continue
        s = os.stat("/etc/.bzr")
        if s[stat.ST_UID] != 0:
            raise nagios_plugin.CriticalError("%s is not owned by root" % (directory))
        if s[stat.ST_GID] != 4:
            raise nagios_plugin.CriticalError("%s is not group owned by adm" % (directory))
        if stat.S_IMODE(s[stat.ST_MODE]) != 1528:
            raise nagios_plugin.CriticalError("%s permissions are broken" % (directory))

############################################################

def main():
    nagios_plugin.try_check(check_perms_and_ownership)
    nagios_plugin.try_check(check_up_to_date)
    print "/etc/ bzr tree up-to-date and permissions sane"

################################################################################

if __name__ == "__main__":
    main()
