#!/bin/bash

# 
# Author Omar Refai
# Copyright Canonical LTD 2011

set -e
set -u

USAGE="Usage: You must provide an instance name, and numeric threshold values for Current and Max Queue 
    ex. check_haproxy_queue_depth lpnet-app 0 100"

if [ $# != 3 ] ; then
    echo "$USAGE"
    exit 1
fi

if ! [[ "$2" =~ ^[0-9]+$ ]] ||  ! [[ "$2" =~ ^[0-9]+$ ]] ; then
    echo "error, threshold values need to be integers"
    echo "$USAGE"
    exit 1
fi

HAPROXYUSERPASS=$(grep auth /etc/haproxy/haproxy.cfg | awk '{print $NF}')
HAPrxyStats=$(wget -O- "http://$HAPROXYUSERPASS@localhost:10000/;csv;norefresh" -q)

exists=0
stanzas=$(echo $HAPrxyStats| xargs -n1 | grep BACKEND | awk -F , '{print $1}')
for i in $stanzas ; do 
    if [ "$1" == "$i" ] ; then 
        exists=$((exists+1))
    fi
done

if [[ "$exists" == 0 ]] ; then
    echo "Instance you are looking for does not exist. Available instances:
 
$stanzas"
    exit 1
else
    for stanza in "$1" ; do
        CURRQ=$(echo "$HAPrxyStats" | grep $stanza | grep BACKEND | cut -d , -f 3)
        MAXQ=$(echo "$HAPrxyStats"  | grep $stanza | grep BACKEND | cut -d , -f 4)
    done

    CURRQthrsh=$2
    MAXQthrsh=$3

    if [[ $CURRQ -gt $CURRQthrsh || $MAXQ -gt $MAXQthrsh ]] ; then 
        echo "CRITICAL QUEUE DEPTH for $stanza - CURRENT:$CURRQ MAX:$MAXQ"
        exit 2
    else
        echo "Queue depth for $stanza is okay CURRENT:${CURRQ} MAX:$MAXQ"
        exit 0
    fi
fi
