#!/usr/bin/env python

# Copyright (C) 2009  James Troup <james.troup@canonical.com>

################################################################################

import nagios_plugin
import glob

###########################################################################

def compare_expected(line, expected, type, interface):
    expected = expected.strip().lower()
    value = line.split(":")[1].strip().lower()
    if value != expected:
        raise nagios_plugin.CriticalError(
            "%s: %s is '%s' not '%s'" % (interface, type, value, expected))

################################################################################

## Example ethtool output:

# Settings for eth0:
#         Supported ports: [ TP ]
#         Supported link modes:   10baseT/Half 10baseT/Full
#                                 100baseT/Half 100baseT/Full
#                                 1000baseT/Half 1000baseT/Full
#         Supports auto-negotiation: Yes
#         Advertised link modes:  10baseT/Half 10baseT/Full
#                                 100baseT/Half 100baseT/Full
#                                 1000baseT/Half 1000baseT/Full
#         Advertised auto-negotiation: Yes
#         Speed: 1000Mb/s
#         Duplex: Full
#         Port: Twisted Pair
#         PHYAD: 1
#         Transceiver: internal
#         Auto-negotiation: on
#         Supports Wake-on: g
#         Wake-on: g
#         Current message level: 0x000000ff (255)
#         Link detected: yes

def check_interface(filename, interface, expected_speed="1000MB/s"):
    nagios_plugin.check_file_freshness(filename, 2*3*60*60)
    input_file = open(filename)
    link_status = False
    for line in input_file.readlines():
        line = line.lstrip()
        if line.startswith("Speed: "):
            compare_expected(line, expected_speed, "speed", interface)
        if line.startswith("Duplex: "):
            compare_expected(line, "Full", "duplex", interface)
        if line.startswith("Link detected: "):
            compare_expected(line, "Yes", "link detected", interface)
            link_status = True
    # We can't error out on lack of speed/duplex as Xen guest or
    # bridge interfaces don't have them.

    # On the other hand, we can error out if we don't find any 'link
    # detected' line.  This check should simply be disabled on any
    # hardware (e.g. hppa) which is so pre-historic it doesn't even
    # support ethtool.
    if not link_status:
        raise nagios_plugin.CriticalError(
            "%s: did not find link detected information" % (interface))

################################################################################

def main():
    interfaces = []
    for filename in glob.glob("/var/lib/nagios/ethtool.*eth*"):
        interface = filename.split(".")[-1]
        nagios_plugin.try_check(check_interface, filename, interface)
        interfaces.append(interface)
    print "All OK on: %s" % (", ".join(interfaces))

if __name__ == "__main__":
    main()
