#!/usr/bin/env python
# Copyright 2008 Canonical Ltd.  All rights reserved.
# Author: Stuart Metcalfe and Danny Tamez

import sys
import urllib2
from optparse import OptionParser

# Required exit status codes for Nagios
OK = 0
WARNING = 1
CRITICAL = 2
UNKNOWN = 3

try:
    import simplejson as json
except ImportError:
    print 'CHECK_FORMS UNKNOWN: simplejson is not available'
    sys.exit(UNKNOWN)

class NagiosOptionParser(OptionParser):
    """An ooption parser that exits with status 3 instead of default 2"""
    def error(self, msg):
        print msg
        sys.exit(UNKNOWN)

def main():
    usage = "usage: %prog [options] http://hostname.com"
    parser = NagiosOptionParser(usage=usage, version="%prog 1.0")
    parser.add_option("-w", "--warning", dest="warning_threshold", type="int",
                      help="the number of errors needed to produce a warning alert",
                      default=2)
    parser.add_option("-c", "--critical", dest="critical_threshold", type="int",
                      help="the number of errors needed to produce a critical alert",
                      default=5)
    (options, args) = parser.parse_args()
    if len(args) != 1:
        parser.error('CHECK_FORMS UNKNOWN: a base url must be provided')

    base_url = args[0]
    errors = []

    if base_url.endswith('/'):
        base_url = base_url[:-1]

    try:
        f = urllib2.urlopen('%s/selfreport/' % base_url)
        data = json.load(f)
    except Exception, e:
        print """CHECK_FORMS UNKNOWN: Error while fetching data from %s/selfreport/
    The exception was %s""" % (base_url, e)
        sys.exit(CRITICAL)

    for form in data:
        try:
            f = urllib2.urlopen(base_url + form['url'])
            if len(f.read()) < 1:
                print "CHECK_FORMS CRITICAL: The form %s was empty." % form
                sys.exit(CRITICAL)
        except urllib2.HTTPError, e:
            errors.append(form['url'])

    msg = 'Checked %d forms. %d errors.' % (len(data), len(errors))
    if len(errors) < options.warning_threshold:
        print 'CHECK_FORMS OK: ' + msg
        sys.exit(OK)
    elif len(errors) < options.critical_threshold:
        print 'CHECK_FORMS WARNING: ' + msg
        sys.exit(WARNING)
    else:
        print 'CHECK_FORMS CRITICAL: ' + msg
        sys.exit(CRITICAL)

if __name__ == '__main__':
    main()
