#!/bin/bash

# Copyright (C) 2011 Canonical Ltd.
# Author Haw Loeung
#
# Script used to query the Landscape database checking for computers where
# there are more than 1 consecutive errors. If there are more than a certain
# number of these computers, then alert. RT#46375.
#

set -eu

if [[ $# -ne 2 ]] || [[ $2 =~ [[:alpha:][:punct:]] ]]; then
	echo "$0 [database] [number of computers to alert]"
	exit 1
fi

ERRCOUNT=$(psql -A -q -t -d $1 -c "SELECT COUNT(1) FROM computer WHERE consecutive_errors > 1")
RET=$?
if [[ ${RET} -ne 0 ]]; then
	echo "ERROR: Failed to connect to $1 - ERRCODE ${RET}"
	exit 2
fi

if [[ ${ERRCOUNT} -lt $2 ]]; then
	echo "OK: Current consecutive errors is only at ${ERRCOUNT}"
	exit 0
else
	echo "ERROR: Too many consecutive errors - ${ERRCOUNT}. Please escalate this to the Landscape developers. See RT#46375."
	exit 2
fi
