#!/bin/bash

# Author: Tom Haddon
# Copyright: Canonical, Ltd. 2009

# This script checks that there's been a heartbeat entry
# in the landscape-sync logfile in the last five minutes.
# It takes the location of the logfile as an argument

set -e
set -u

THRESHOLD=600

LOGFILE=$1

LAST_HEARTBEAT=$(grep 'HEARTBEAT::landscape-sync' $LOGFILE | tail -1 | cut -d, -f1)

if [ -z "$LAST_HEARTBEAT" ]; then
    echo "No heartbeat found in logfile"
    exit 2
fi

let INTERVAL=$(date +%s)-$(date +%s --date="$LAST_HEARTBEAT")

if [ $INTERVAL -gt $THRESHOLD ]; then
    echo "Heartbeat not seen in over $THRESHOLD seconds - $INTERVAL seconds"
    exit 2
else
    echo "Heartbeat seen in last $THRESHOLD seconds"
    exit 0
fi
