#!/usr/bin/env python

# Copyright (C) 2008 James Troup <james.troup@canonical.com>
"""whatever"""

import optparse
import sys
import types

from ConfigParser import ConfigParser

sys.path.insert(0, "/var/lib/mailman")

from Mailman import mm_cfg
from Mailman import MailList
from Mailman import Utils
from Mailman import Errors

NAGIOS_OK=0
NAGIOS_WARN=1
NAGIOS_FAIL=2

class nagios_warning:
    def __init__(self):
        self.warning = ""
    def add(self, line):
        self.warning += line + "\n"

class SeriousConfigParser(ConfigParser):
    def get_list(self, section, option, raw=False, vars=None):
        """Look up OPTION in SECTION and return it as a list of words."""
        return self.get(section, option, raw, vars).split()

def check_list(ccc, listname, warning):
    config = {}
    ret_val = NAGIOS_OK
    mlist = MailList.MailList(listname, lock=0)
    for category in mm_cfg.ADMIN_CATEGORIES:
        subcats = mlist.GetConfigSubCategories(category)
        if subcats is None:
            decode_config(mlist, category, None, config)
        else:
            for subcat in [t[0] for t in subcats]:
                decode_config(mlist, category, subcat, config)

    # Rules are as follows:
    #   All lists must require subscription confirmation by the user
    #   Canonical lists
    #     Must be archived
    #     Archives must be private
    #     Must not be advertised
    #     Subscription must require approval
    #   Ubuntu lists  host_name == lists.ubuntu.com
    #     Must be archived
    #     Archives must be publicarchive == True
    #     Must be advertised
    #     Subscription shouldn't require approval
    #       archive_private == 0

    if config["subscribe_policy"] == "2":
        print "E: list '%s' doesn't require subscription confirmation" % (listname)
        ret_val = NAGIOS_FAIL

    # public lists on lists.canonical.com
    public_canonical_lists = ccc.get_list("list_sanity", "public_canonical_lists")

    # Council lists and the like
    not_really_public = ccc.get_list("list_sanity", "not_really_public")
    
    # Usually lists which are too high traffic and break pipersnail
    public_but_not_archived = ccc.get_list("list_sanity", "public_but_not_archived")

    # Private Canonical lists but with external (not @canonical.com) subscribers
    private_with_external = ccc.get_list("list_sanity", "private_with_external")

    # Private Canonical lists with individual external whitelist addresses
    # Config format is "list_name:user@domain.com,user2@domain2.com"
    private_whitelist_addresses = []
    for private_external in ccc.get_list("list_sanity", "private_with_individual_external"):
        (private_list, private_members) = private_external.split(':')
        if not listname == private_list:
            continue
        for private_member in private_members.split(','):
            private_whitelist_addresses.append(private_member)

    if config["host_name"] == "lists.canonical.com" and listname not in public_canonical_lists:
        if config["advertised"] not in [ "False", "0" ]:
            print "E: private list '%s' is advertisted publicly ('%s')" % (listname, config["advertised"])
            ret_val = NAGIOS_FAIL
        if config["archive"] not in [ "True", "1" ]:
            print "E: private list '%s' is not archived ('%s')" % (listname, config["archive"])
            ret_val = NAGIOS_FAIL
        if config["archive_private"] not in [ "True", "1" ]:
            print "E: private list '%s' has public archives ('%s')" % (listname, config["archive_private"])
            ret_val = NAGIOS_FAIL
        if config["subscribe_policy"] != "3":
            print "E: private list '%s' does not require subscription approval ('%s')" % (listname, config["subscribe_policy"])
            ret_val = NAGIOS_FAIL
        if listname not in private_with_external:
            members = mlist.getRegularMemberKeys()
            members.extend(mlist.getDigestMemberKeys())
            for member in members:
                if member in private_whitelist_addresses:
                    continue
                if not member.endswith("@canonical.com") and not member.endswith("@rt.canonical.com") and not member.endswith("@lists.canonical.com"):
                    print "E: private list '%s' has non-canonical.com subscribers ('%s')" % (listname, member)
                    ret_val = NAGIOS_FAIL
    elif config["host_name"] == "lists.ubuntu.com" or listname in public_canonical_lists:
        if config["advertised"] not in [ "True", "1" ] and listname not in not_really_public:
            warning.add("WARN: %s@%s is not advertisted publicly ('%s')" % (listname, config["host_name"], config["advertised"]))
        if config["archive"] not in [ "True", "1" ] and listname not in public_but_not_archived:
            warning.add("WARN: %s@%s is not archived" % (listname, config["host_name"]))
        if config["archive_private"] not in [ "False", "0" ] and listname not in not_really_public:
            warning.add("WARN: %s@%s doesn't have public archives ('%s')" % (listname, config["host_name"], config["archive_private"]))
        if config["subscribe_policy"] == "3" and listname not in not_really_public:
            warning.add("WARN: %s@%s requires subscription approval" % (listname, config["host_name"]))
    elif config["host_name"] in [ "lists.sa-piac.net", "lists.catherdersanon.org" ]:
        # whatever, don't care
        return ret_val
    else:
        print "E: %s has invalid host name '%s'" % (listname, config["host_name"])
        ret_val = NAGIOS_FAIL
    return ret_val

def decode_config(mlist, category, subcat, config):
    info = mlist.GetConfigInfo(category, subcat)
    if not info:
        return
    for data in info[1:]:
        if not isinstance(data, types.TupleType):
            continue
        varname = data[0]
        if varname not in [ "host_name", "archive", "advertised",
                            "archive_private", "subscribe_policy" ]:
            continue
        value = getattr(mlist, varname)
        if not isinstance(value, types.StringType):
            value = repr(value)
        config[varname] = value

################################################################################

def main():
    parser=optparse.OptionParser()
    parser.add_option("-v","--verbose", action="store_true", dest="verbose")
    
    (options,args)=parser.parse_args()

    warning = nagios_warning()
                                
    ccc = SeriousConfigParser()
    ccc.readfp(file("/etc/nagios/cat-checks.conf"))

    names = Utils.list_names()
    names.sort()
    ret_val = NAGIOS_OK
    for n in names:
        ret = check_list(ccc, n, warning)
        if ret > ret_val:
            ret_val = ret
    if ret_val == NAGIOS_FAIL:
	sys.exit(ret_val)

    if options.verbose and warning.warning:
        print warning.warning,
        sys.exit(NAGIOS_WARN)

################################################################################

if __name__ == "__main__":
    main()
    
