#!/bin/sh

# Copyright (c) 2009 Canonical, Ltd
# Author: Tom Haddon

# Plugin to check the number of 5XXs across LP application
# servers. We graph this information by querying +opstats
# and then throwing that data into lpstats.canonical.com.
# This plugin is querying that database.

set -e
set -u

THRESHOLD=$1

SQL="SELECT SUM(VALUE) 
    FROM graphs_datum 
    WHERE timestamp > (NOW() - INTERVAL '5 MINUTES') 
    AND metric_id IN (
        SELECT id 
        FROM graphs_metric 
        WHERE key = '5XXs_b' 
        AND datafile_id IN (
            SELECT id 
            FROM graphs_datafile 
            WHERE filename LIKE 'edge%opstats' 
            OR filename LIKE 'production%opstats'
            )
        )"

FIVEXXS=$(psql -t -U ro monitor -c "$SQL" | sed -e 's/ //g')

if [ $? != 0 ]
then
    echo "Error querying 5XXs: $FIVEXXS"
    exit 3
fi

if [ $(echo "${FIVEXXS}>${THRESHOLD}"|bc) = 1 ]; then
    echo "ERROR: $FIVEXXS in the last 5 minutes"
    exit 2
else
    echo "OK: $FIVEXXS in the last 5 minutes"
    exit 0
fi

