#!/bin/bash

# Author: Tom Haddon
# Modified by: Stefan Stasik
# Copyright: Canonical, Ltd. 2009, 2010

# This script checks that there's been a mark entry
# in the Launchpad mailman/logs/xmlrpc logfile in the last 20 minutes.
# It takes the location of the logfile as an argument.
# This is templated off of Tom's check_landscapesync_heartbeat script. 

set -e
set -u

THRESHOLD=2400

LOGFILE=$1

LAST_MARK=$(grep 'MARK' $LOGFILE | tail -1 | cut -d\( -f1)

if [ -z "$LAST_MARK" ]; then
    echo "No mark found in logfile"
    exit 2
fi

let INTERVAL=$(date +%s)-$(date +%s --date="$LAST_MARK")

if [ $INTERVAL -gt $THRESHOLD ]; then
    echo "Mark not seen in over $THRESHOLD seconds - $INTERVAL seconds"
    exit 2
else
    echo "Mark seen in last $THRESHOLD seconds"
    exit 0
fi
