#!/usr/bin/env python

# Check which packages are out of date
# Copyright (C) 1997-2010  James Troup <james.troup@canonical.com>

################################################################################

import sys

import warnings

# Ignore warnings from hardy's python-apt about the API not being stable
warnings.filterwarnings("ignore", category=FutureWarning, append=1)

import apt
import apt_pkg

import nagios_plugin

################################################################################

def read_status():
    pkgs = {}
    Status = apt_pkg.ParseTagFile(open("/var/lib/dpkg/status"))
    while Status.Step():
        (desired, _, status) = Status.Section.Find('Status').split()
        if status != "installed":
            continue
        name = Status.Section.Find('Package')
        version = Status.Section.Find('Version')
        if pkgs.has_key(name):
            raise nagios_plugin.CriticalError(\
                "Duplicate entry for '%s' in status file." % (name))
        pkgs[name] = [version, desired]
    return pkgs

################################################################################

def main():
    apt_pkg.init()

    cache = apt.Cache()
    installed = read_status()

    if not hasattr(apt_pkg, 'VERSION'):
        hardy_python_apt = True
    else:
        hardy_python_apt = False

    critical_ood = set()
    warn_ood = set()
    for pkg in installed.keys():
        # 'pkg in cache' doesn't work with python-apt in hardy \o/
        if not cache.has_key(pkg):
            print "%s not found in apt cache?!" % (pkg)
            continue
        if hardy_python_apt:
            available_version = cache[pkg].candidateVersion
        else:
            available_version = cache[pkg].candidate.version
        if apt_pkg.VersionCompare(installed[pkg][0], available_version) < 0:
            if hardy_python_apt:
                source_pkg = cache[pkg].sourcePackageName
                origins = cache[pkg].candidateOrigin
            else:
                source_pkg = cache[pkg].candidate.source_name
                origins = cache[pkg].candidate.origins
            is_security = False
            for origin in origins:
                if '-security' in origin.archive:
                    is_security = True
            if is_security:
                critical_ood.add(source_pkg)
            else:
                warn_ood.add(source_pkg)

    msg = ""
    if critical_ood:
        msg += "[SECURITY] "
        for source_pkg in critical_ood:
            msg += "%s, " % (source_pkg)
        msg = msg[:-2]

    if warn_ood:
        if msg:
            msg += " / "
        msg += "[Updates] "
        for source_pkg in warn_ood:
            msg += "%s, " % (source_pkg)
        msg = msg[:-2]

    if not msg:
        msg = "OK - Packages up-to-date."
    else:
        if len(msg) > 53:
            msg = "%s[...]" % (msg[:53])

    if critical_ood or warn_ood:
        print "WARN: %s" % (msg)
        sys.exit(1)
    else:
        print msg
        sys.exit(0)

################################################################################

if __name__ == "__main__":
    main()
