#!/bin/bash

#
# DESCRIPTION:
#
#    Nagios plugin to check if rsync has had consecutive critical errors
#    recently in some huge log of rsync output, such as generated by
#    oemreposync on greenplum.
#

set -e 
set -u

. /usr/lib/nagios/plugins/utils.sh

while getopts l:e:f: OPTION
do
    case "$OPTION" in
	    l) CHECKLINES=${OPTARG} ;;
	    e) ERRORHITS=${OPTARG} ;;
	    f) LOGFILE="${OPTARG}" ;;
            [?]) print >&2 "Usage: $0 [-l] [-e] [-f]"
		exit 1;;
    esac
done

if [ `tail -n ${CHECKLINES} ${LOGFILE} | grep -c "IO (code"` -gt ${ERRORHITS} ] ; then
   ${ECHO} "CRITICAL - consecutive rsync update errors in ${LOGFILE}"
   exit ${STATE_CRITICAL}
else
   ${ECHO} "OK - oemreposync"
   exit ${STATE_OK}
fi
