#!/bin/bash

# Copyright (C) 2011 Canonical Ltd.
# Author Haw Loeung
#
# Script used to query the U1 database checking the provided storage shards
# and alerting if it is above a certain threshold
#

set -u

if [[ $# -lt 1 ]]; then
	echo "$0 [[shardX:threshold]...]"
	exit 1
fi

DATABASE='ubunet_production_storage'

EC=0
for i in $*; do

	# Validate input provided to make sure it's shardX:YYYY
	shard_id=''
	threshold=''
	if [[ $i =~ ^shard([[:digit:]]+):([[:digit:]]+)$ ]]; then
		shard_id=${BASH_REMATCH[1]}
		threshold=${BASH_REMATCH[2]}
	else
		continue
	fi

	# Now do the SQL query to see what the current count for shardX is
	output=$(psql -A -q -t -d ubunet_production_storage -c "SELECT COUNT(id), shard_id FROM storageuser WHERE shard_id = 'storage_shard${shard_id}' GROUP BY shard_id;")
	RET=$?
	if [[ ${RET} -ne 0 ]]; then
		echo "ERROR: Failed to connect to DB - ERRCODE ${RET}"
		exit 2
	fi

	# Is there output for shardX? Or is it a non-existent shard?
	count=0
	if [[ ${output} =~ ^([[:digit:]]+)\|storage_shard${shard_id}$ ]]; then
		count=${BASH_REMATCH[1]}
	else
		echo "ERROR: Invalid storage shard: shard${shard_id}"
		EC=2
		continue
	fi

	# Now check to see if it exceeds the defined threshold
	if [[ ${count} -gt ${threshold} ]]; then
		echo "ERROR: Storage shard shard${shard_id} exceeded threshold of ${threshold}"
		EC=2
	fi
done

if [[ ${EC} -eq 0 ]]; then
	echo "OK: Storage shards all below thresholds"
fi

exit ${EC}
