#!/bin/bash

#
# DESCRIPTION:
#
#    Nagios plugin to do some basic sanity checks on the userdir-ldap
#    replication process (ud-replicate).
#
#    Probably should be run by nagios-nrpe at least once per day. 
#    This is assumed in the date check below. Change 'HOURS_DIFF' if this 
#    doesn't suit you.
#

set -e 
set -u

. /usr/lib/nagios/plugins/utils.sh

HOURS_DIFF=${1:-24}

export PATH=/sbin:/bin:/usr/sbin:/usr/bin

LINK=/var/lib/misc/ssh-rsa-shadow
TARGET=$( readlink -e ${LINK} )
TARGET=${TARGET%%/ssh-rsa-shadow}
TARGET=${TARGET##/var/lib/misc/}
HOST=$( hostname -f )

if ! grep --quiet '^passwd:.*compat' /etc/nsswitch.conf; then
   ${ECHO} "Host isn't setup for 'compat' auth in /etc/nsswitch.conf"
   exit ${STATE_CRITICAL}
fi

if [ ! -L ${LINK} ]; then
   ${ECHO} "Symlink doesn't exist. Do you need to run 'ud-replicate'?"
   exit ${STATE_CRITICAL}
fi

if [ "${HOST}" != "${TARGET}" ]; then
    ${ECHO} "Symlink doesn't match hostname. Check /etc/hosts file."
    exit ${STATE_CRITICAL}
fi

case ${HOURS_DIFF} in
    [0-9]*);;
    *)
        ${ECHO} "Argument is not an integer."
        exit ${STATE_CRITICAL}
        ;;
esac

if [ ${HOURS_DIFF} -lt 1 ]; then
    HOURS_DIFF=24
fi

MOD_DATE=$( stat --terse --printf="%Y" ${LINK} )
TEST_DATE=$( date "+%s" --date="${HOURS_DIFF} hours-ago" )

if [ ${MOD_DATE} -lt ${TEST_DATE} ]; then
    ${ECHO} "Symlink is out of date. Is the replication running?"
    exit ${STATE_CRITICAL}
fi

exit ${STATE_OK}
