#!/bin/bash

set -e
set -u

LOGKILL="/var/log/chroot_process_kill.log"
TMPFILE=$(mktemp)
getent passwd >$TMPFILE
USERS=$(diff --context=0 /etc/passwd $TMPFILE | grep ":x:" | sed -e 's/:.*//g' | awk '{ print $2 }')

EXCLUDE="dchroot|ubuntu-archive"

for i in $USERS ; do
  EXCLUDE="$EXCLUDE|$i"
done

PROCLIST=$(mktemp)
ORIGLIST=$(mktemp)
FINLIST=$(mktemp)

do_cleanup() {
  rm $TMPFILE
  rm $PROCLIST
  rm $ORIGLIST
  rm $FINLIST
}

set +e
# The following line now includes an egrep -v to remove su processes running as root
# This is necessary because of the way breezy handles su.
# When a user uses dchroot to get into the breezy chroot, it su's to their user, 
#  but the top level su still shows up as root, so it will not be ignored by
#  the $EXCLUDE list.
lsof +c0 2>/dev/null | grep /srv/chroots/ | egrep -vw "($EXCLUDE)" | egrep -v "^su +[0-9]+[ ]+root .*" >$ORIGLIST
cat $ORIGLIST | awk '{ print $2 }' | sort -un >$PROCLIST
set -e

for i in $(cat $PROCLIST) ; do
  grep $i $ORIGLIST | head -1 | awk '{ printf ("%6s %20s %s\n", $2, $3, $1, $9) }'  >>$FINLIST
done

if [ "$#" = "0" ] ; then
  ARG="--check"
else
  ARG="$1"
fi

case $ARG in
  --list)
    echo "   PID              Command PWD"
    cat $FINLIST
    ;;
  --kill)
    echo "Killing:"
    echo "   PID              Command PWD"
    cat $FINLIST
    echo ""
    echo -n "Are you sure? (y/n): "
    read SURE

    if [ "$SURE" = "y" ]; then
      date -R >>$LOGKILL
      cat $PROCLIST >>$LOGKILL
      cat $PROCLIST | awk '{ print $1 }' | xargs kill
    else
      echo "User abort"
    fi
    ;;
  --check)
    NUM=`cat $PROCLIST | wc -l`
    if [ $NUM -gt 0 ]; then
      echo "FAIL: $NUM suspect processes running"
      do_cleanup
      exit 2
    else
      echo "OK: No suspect processes"
      do_cleanup
      exit 0
    fi
    ;;
  *)
    echo "Error: $ARG not a valid argument"
    do_cleanup
    exit 2
    ;;
esac

do_cleanup
