#!/usr/bin/python
###
### Check the loadbalancer results
###     loadbalancer_test.py
###
### Requires a config file:
###   /etc/nagios/loadbalancer_test_settings
###
###   Which is basically a python formatted file.
###   Contains the settings:
###
###     # Username and password to connect to loadbalancer via URL
###     USERNAME = '<username>'
###     PASSWORD = '<password>'
###     # URL of the loadbalancer
###     URL = '<url>'
###     # Dictionary of workers
###     WORKERS = { 'lpnet1': 'http://gangotri.canonical.com:9031', .... }
###     
###     # REALM is not used
###
### -------------------------------------
### This script checks for:
### - that the defined workers are returning Ok
### - that the defined workers are in the resulting page
### - that any new workers, not in the config dictionary, cause a CRITICAL error
###

import base64
import re
import sys
import urllib2


def main():

    # Get our config variables
    sys.path.append("/etc/nagios/")
    from loadbalancer_test_settings import URL, REALM, USERNAME, PASSWORD, WORKERS

    # Construct the URL request
    request = urllib2.Request(URL)
    base64string = base64.encodestring('%s:%s' % (USERNAME, PASSWORD))[:-1]
    request.add_header("Authorization", "Basic %s" % base64string)

    # Get the page output into the data variable
    data = urllib2.urlopen(request).read()

    ERROR = False
    ERROR_UNKNOWN_WORKER = False
    i = 0
    bad_workers = []
    good_workers = []
    unknown_workers = [ ]

    # Split the entire page around the html tags < & >
    data_split = re.split('[<>]+', data)
    # Loop through each element - looking for the "balance manager" href
    while i < len(data_split):
        result = data_split[i].find('a href="/balancer-manager?b=')
        if result >= 0:
            WORKER_EXISTS = False
            # Now check if each worker is "in the loop"
            for worker in WORKERS:
                if WORKERS[worker] == data_split[i + 1]:
                    # Is in the config, check is returning "Ok"
                    #   and then remove from list of WORKERS; thus looking for any leftovers
                    WORKER_EXISTS = True
                    check = re.search("^Ok$", data_split[i + 15])
                    if not check:
                        ERROR = True
                        bad_workers.append(worker)
                    else:
                        good_workers.append(worker)
                    del WORKERS[worker]
                    break

            # Does this worker exist in our list of configured workers?
            #   If False, then, no. Is a new worker, and hence a config error
            if not WORKER_EXISTS:
                ERROR_UNKNOWN_WORKER = True
                unknown_workers.append(data_split[i + 1])
        i += 1

    # Any leftover workers?
    for worker in WORKERS:
        ERROR = True
        bad_workers.append(worker)

    if ERROR:
        # We're currently returning CRITICAL if any workers are out of the loop.
        # This may be changed depending on how we want to be alerted...
        print "LOAD BALANCER CRITICAL: The following workers are NOT ACTIVE: %s" % ", ".join(sorted(bad_workers))
        return 2
    if ERROR_UNKNOWN_WORKER:
        # return CRITICAL if we have any new workers not in config
        print "LOAD BALANCER CRITICAL: unknown workers: %s" % ", ".join(sorted(unknown_workers))
        return 2

    print "LOAD BALANCER OK: The following workers are ACTIVE: %s" % ", ".join(sorted(good_workers))
    return 0

if __name__=="__main__":
    import traceback
    try:
        return_code = main()
    except:
	traceback.print_exc(file=sys.stdout)
        sys.exit(3)
    sys.exit(return_code)
