#!/bin/bash

# DESCRIPTION:
#
#	Indicates whether the UPS pairs are overloaded.
#	The script will accept a pair of hostnames to check.
#
#	The current pairs are:
#		* 1/8
#		* 2/3
#		* 4/5
#		* 6/7
#		* 9/10
#		* 11/12
#		* 13/14
#
#	If the sum of the percentage load of each pair is greater than 100%
#	then the status is critical.
#
#	SNMP OID: upsAdvOutputLoad
# 	1.3.6.1.4.1.318.1.1.1.4.2.3.0
#

. /usr/lib/nagios/plugins/utils.sh

WARN=95
CRITICAL=100

OID="1.3.6.1.4.1.318.1.1.1.4.2.3.0"

if [ ${#} -ne 2 ]; then
	echo "Usage: ${0} <hostname> <hostname>"
	exit 1
fi

HOST_1=${1}
HOST_2=${2}

UPS_LOAD_HOST_1=$(/usr/bin/snmpwalk -v 1 -c public $HOST_1 ${OID} | sed -e "s/.*: //")
UPS_LOAD_HOST_2=$(/usr/bin/snmpwalk -v 1 -c public $HOST_2 ${OID} | sed -e "s/.*: //")

if [ -z ${UPS_LOAD_HOST_1} ] || [ -z ${UPS_LOAD_HOST_2} ]; then
	echo "Cannot determine the UPS load"
	exit ${STATE_CRITICAL}
fi

TOTAL_LOAD=$( expr ${UPS_LOAD_HOST_1} + ${UPS_LOAD_HOST_2} )

echo "Combined load of ${HOST_1} and ${HOST_2} at ${TOTAL_LOAD}"

if [ ${TOTAL_LOAD} -lt ${WARN} ]; then
	exit ${STATE_OK}
elif [ ${TOTAL_LOAD} -lt ${CRITICAL} ]; then
	exit ${STATE_WARNING}
else
	exit ${STATE_CRITICAL}
fi
